Learn R Programming

DCchoice (version 0.0.14)

summary.sbchoice: Summarizing sbchoice estimation

Description

Summary method for objects of class sbchoice.

Usage

## S3 method for class 'sbchoice':
summary(object, \dots)

## S3 method for class 'summary.sbchoice': print(x, digits = max(3, getOption("digits") - 1), ...)

Arguments

object
an object of class "sbchoice".
x
an object of class "summary.sbchoice".
digits
a number of digits to display.
...
optional arguments. Currently not in use.

Value

  • In addition to those available in the object of the "sbchoice" class, the following list components are added.
  • glm.summarya summary of the glm estimation. It is an object of class "summary.glm".
  • glm.null.summarya summary of the glm estimation of the null model (i.e., only with the intercept). It is an object of class "summary.glm".
  • loglikthe value of the log-likelihood of the model.
  • loglik.nullthe value of the log-likelihood of the null model.
  • psdR2McFadden's pseudo-R2 measure.
  • adjpsdR2McFadden's pseudo-R2 measure adjusted for the degrees of freedom.
  • medianWTPthe estimated median WTP.
  • meanWTPthe estimated mean WTP.
  • trunc.meanWTPthe estimated mean WTP truncated at the maximum bid.
  • adj.trunc.meanWTPthe truncated mean WTP with the adjustment of Boyle et~al.(1988).
  • LR.testa vector containing the likelihood ratio test statistic, the degrees of freedom and the associated p-value.
  • AICinformation criterion (AIC and BIC).

Details

The function summary.sbchoice() computes and returns a list of summary statistics of the fitted model in object of the "sbchoice" class.

Some of the values are printed up to certain decimal places. Actual values of individual components are displayed separately, for instance, by summary(object)$coefficients. See the Value section for a list of components. Since the model for the single-bounded dichotomous choice CV data is estimated by glm, an object of class "summary.sbchoice" is constructed based on a "summary.glm" class object. The summary of the "summary.glm" class object is available by summary(object)$glm.summary. Other components computed by summary.glm are also accessible. See summary.glm for details.

References

Boyle KJ, Welsh MP, Bishop RC (1988). Validation of Empirical Measures of Welfare Change: Comment. Land Economics, 64(1), 94--98.

See Also

sbchoice, glm, summary.glm